from io import open
from setuptools import setup


"""
:authors: DarkRastafar
:license: Apache License
:copyright: (c) 2022 DarkRastafar
"""

version = '1.0.0'

long_description = '''smth'''

setup(
    name='glob_custom',
    version=version,
    author='DarkRastafar',
    author_email='alwaysintouch247@gmail.com',
    description=('test'),
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="https://github.com/pypa/sampleproject",

)